summaryrefslogtreecommitdiff
path: root/examples/simple-pim/simple.cpp
Side-by-side diff
Diffstat (limited to 'examples/simple-pim/simple.cpp') (more/less context) (show whitespace changes)
-rw-r--r--examples/simple-pim/simple.cpp39
1 files changed, 20 insertions, 19 deletions
diff --git a/examples/simple-pim/simple.cpp b/examples/simple-pim/simple.cpp
index 029e71b..50905bf 100644
--- a/examples/simple-pim/simple.cpp
+++ b/examples/simple-pim/simple.cpp
@@ -19,5 +19,5 @@
-#include <opie/oapplicationfactory.h> // a template + macro to save the main method and allow quick launching
-#include <opie/otabwidget.h>
-#include <opie/owait.h>
+#include <opie2/oapplicationfactory.h> // a template + macro to save the main method and allow quick launching
+#include <opie2/otabwidget.h>
+#include <opie2/owait.h>
@@ -37,2 +37,3 @@
+using namespace Opie::Core;
OPIE_EXPORT_APP( OApplicationFactory<MainWindow> )
@@ -52,3 +53,3 @@ MainWindow::MainWindow(QWidget *parent, const char* name, WFlags fl )
*/
- m_tab = new OTabWidget(this);
+ m_tab = new Opie::Ui::OTabWidget(this);
@@ -213,3 +214,3 @@ void MainWindow::slotLoad() {
/* we will provide a wait scrren */
- m_loading = new OWait(this, "wait screen" );
+ m_loading = new Opie::Ui::OWait(this, "wait screen" );
}
@@ -278,3 +279,3 @@ void MainWindow::slotShow() {
/* as answer this slot will be called */
-void MainWindow::slotShowRecord( const OPimRecord& rec) {
+void MainWindow::slotShowRecord( const Opie::OPimRecord& rec) {
/* got a parent but still is a toplevel MODAL dialog */
@@ -346,3 +347,3 @@ namespace {
*/
- PIMListViewItem( QListView*, OPimRecord* record );
+ PIMListViewItem( QListView*, Opie::OPimRecord* record );
~PIMListViewItem();
@@ -352,9 +353,9 @@ namespace {
int rtti()const;
- OPimRecord* record()const;
+ Opie::OPimRecord* record()const;
private:
- OPimRecord* m_record;
+ Opie::OPimRecord* m_record;
};
- PIMListViewItem::PIMListViewItem( QListView *p, OPimRecord* rec )
+ PIMListViewItem::PIMListViewItem( QListView *p, Opie::OPimRecord* rec )
: QListViewItem(p), m_record( rec ) {
@@ -367,3 +368,3 @@ namespace {
- OPimRecord* PIMListViewItem::record()const {
+ Opie::OPimRecord* PIMListViewItem::record()const {
return m_record;
@@ -384,3 +385,3 @@ PIMListView::~PIMListView() {
-void PIMListView::set( OTodoAccess::List list ) {
+void PIMListView::set( Opie::OPimTodoAccess::List list ) {
/* clear first and then add new items */
@@ -388,3 +389,3 @@ void PIMListView::set( OTodoAccess::List list ) {
- OTodoAccess::List::Iterator it;
+ Opie::OPimTodoAccess::List::Iterator it;
for (it = list.begin(); it != list.end(); ++it ) {
@@ -392,5 +393,5 @@ void PIMListView::set( OTodoAccess::List list ) {
* make a new item which automatically gets added to the listview
* and call the copy c'tor to create a new OTodo
*/
- PIMListViewItem *i = new PIMListViewItem(this, new OTodo( *it ) );
+ PIMListViewItem *i = new PIMListViewItem(this, new Opie::OPimTodo( *it ) );
i->setText(0, (*it).summary() );
@@ -399,3 +400,3 @@ void PIMListView::set( OTodoAccess::List list ) {
-void PIMListView::set( const OEffectiveEvent::ValueList& lst ) {
+void PIMListView::set( const Opie::OEffectiveEvent::ValueList& lst ) {
/* clear first and then add items */
@@ -403,5 +404,5 @@ void PIMListView::set( const OEffectiveEvent::ValueList& lst ) {
- OEffectiveEvent::ValueList::ConstIterator it;
+ Opie::OEffectiveEvent::ValueList::ConstIterator it;
for ( it = lst.begin(); it != lst.end(); ++it ) {
- PIMListViewItem *i = new PIMListViewItem(this, new OEvent( (*it).event() ) );
+ PIMListViewItem *i = new PIMListViewItem(this, new Opie::OPimEvent( (*it).event() ) );
i->setText( 0, PIMListView::makeString( (*it) ) );
@@ -427,3 +428,3 @@ void PIMListView::showCurrentRecord() {
-QString PIMListView::makeString( const OEffectiveEvent& ev ) {
+QString PIMListView::makeString( const Opie::OEffectiveEvent& ev ) {
QString str;
@@ -392,5 +393,5 @@ void PIMListView::set( OTodoAccess::List list ) {
* make a new item which automatically gets added to the listview
- * and call the copy c'tor to create a new OTodo
+ * and call the copy c'tor to create a new OPimTodo
*/